==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/print.php <==
<? 
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!KWL_CheckLocalReferer()) {
	KWL_Redirect("stories.php?story=$story");
}
if (!$CONF['PrintStory']) die(_DISABLED);
ob_start();
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN">
<HTML>
<HEAD>
<META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=<? echo $rdf_lang ?>">
<TITLE><? echo $CONF['SiteName'] . " - " . $CONF['SiteSlogan']; ?></TITLE>
</HEAD>
<BODY BGCOLOR="#FFFFFF" TEXT="#000000" LINK="#486591" VLINK="#204863" ALINK="#D5AE83">
<?
function print_replys($rid,$toprid,$where,$reply=0) {
	global	$CONF,$LAYOUT,$G_URL;
	global	$comment_sort, $cmode;
	
	if ($CONF["Comments"]) {
		$sql	= "SELECT * FROM T_Comments WHERE ParentRid = '$rid' ";
		$sql .= "ORDER By Birthstamp DESC";
		$result	= SqlQuery($sql);

		if (mysql_num_rows($result)) {
			while ($A = mysql_fetch_array($result)) {	
				if ($reply>0) {
					$tmp	= $reply * 25;
					echo "<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=\"100%\">\n";
					echo "<TR><TD WIDTH=" . $tmp . "><IMG SRC=\"" . $G_URL . "/images.d/speck.gif\" HEIGHT=1 WIDTH=\"" . $tmp . "\"></TD>\n<TD>\n";
				}
				echo _AUTHOR . ": " . $A["Author"]
				     . "<BR>"
					  . _POSTEDON . ": " . KWL_DateFormat($A["Birthstamp"])
					  . "<P>";
				echo KWL_ParseContent($A["Content"],$CONF[Reply_PLevel]);
				echo "<HR>";

				if ($reply) echo "</TD></TR></TABLE>\n";
					$sql	= "SELECT * from T_Comments ";
					$sql .= "WHERE ParentRid = '" . $A["Rid"] . "' ";
					$sql .= "AND TopRid = '" . $toprid . "' ";
					$sql .= "ORDER By Birthstamp DESC";
					$tresult	= SqlQuery($sql);
					if (mysql_num_rows($tresult)) {
						$tmp	= $reply + 1;
						print_replys($A["Rid"],$toprid,$where,$tmp);
					}
					mysql_free_result($tresult);
			}
		mysql_free_result($result);
		}
	}
}

echo "<!-- " . _PRINTFRIEND . " -->\n\n";
$A = SqlQueryFetchArray("SELECT * FROM T_Stories WHERE Rid = '$story'");

if (!$A) {

	$VAR["Heading"] = _NOSTORY;
	$VAR["Content"] = "<br>" . _NOSTORY . "<br><br>";
	KWL_DrawMain($VAR);

} else {
	
	$content = KWL_ParseContent($A["Content"],$A["ParseLevel"]);

	echo "<FONT SIZE=\"+1\">"
     . _TITLE  . ": <B>$A[Heading]</B>"
	  . "</FONT><P>"
	  . _AUTHOR . ": $A[Author]<BR>"
	  . _POSTEDON . ": " . KWL_DateFormat($A["Birthstamp"]) . "<BR>"
	  . "URL : <A HREF=\"$G_URL/?story=$story\">$G_URL/?story=$story</A>"
	  . "<BR>\n<HR>\n"
	  . $content;
	  
	if ($A['bofile']) {
		echo "<P>\n<LI>". _ATTCHED_FILE .": "
		   . "<a href=\"$G_URL/upload/$A[Topic]/$A[bcfile]/$A[bofile]\">"
			. KWL_icon_check($A['bofile'])
			. "$A[bofile]</a> (" . KWL_FileHSize($A['bfsize'],1) . ")\n"
			. KWL_file_view($A['Topic'],$A['bcfile'],$A['bofile']);
	}
	
	echo "\n<HR>\n";

	if ($A['replys']) {
		if (!$reply) {
			echo "<a href=\"print.php?story=$story&reply=yes\">"._COMMENTS."($A[replys])</a><BR>";
		} else {
			print_replys($story,$story,"",0);
		}
	}
}
echo "<div align=right><A HREF=\"$CONF[G_URL]\">" . htmlspecialchars($CONF["SiteName"]) . "</A>" . " - " . htmlspecialchars($CONF["SiteSlogan"]) . "</div>\n" ;
?>
</BODY>
</HTML>
<?
$content = ob_get_contents();
ob_end_clean();
print $content;
ob_start();
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/print.php <==
<? 
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
if (!KWL_CheckLocalReferer()) {
	KWL_Redirect("stories.php?story=$story");
}
if (!$CONF['PrintStory']) die(_DISABLED);
ob_start();
settype($reply,"string");
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0//EN">
<HTML>
<HEAD>
<META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=<? echo $rdf_lang ?>">
<TITLE><? echo $CONF['SiteName'] . " - " . $CONF['SiteSlogan']; ?></TITLE>
</HEAD>
<BODY BGCOLOR="#FFFFFF" TEXT="#000000" LINK="#486591" VLINK="#204863" ALINK="#D5AE83">
<?
function print_replys($rid,$toprid,$where,$reply=0) {
	global	$CONF,$LAYOUT,$G_URL;
	global	$comment_sort, $cmode;
	
	if ($CONF["Comments"]) {
		$sql	= "SELECT * FROM T_Comments WHERE ParentRid = '$rid' ";
		$sql .= "ORDER By Birthstamp DESC";
		$result	= SqlQuery($sql);

		if (mysql_num_rows($result)) {
			while ($A = mysql_fetch_array($result)) {	
				if ($reply>0) {
					$tmp	= $reply * 25;
					echo "<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=\"100%\">\n";
					echo "<TR><TD WIDTH=" . $tmp . "><IMG SRC=\"" . $G_URL . "/images.d/speck.gif\" HEIGHT=1 WIDTH=\"" . $tmp . "\"></TD>\n<TD>\n";
				}
				echo _AUTHOR . ": " . $A["Author"]
				     . "<BR>"
					  . _POSTEDON . ": " . KWL_DateFormat($A["Birthstamp"])
					  . "<P>";
				echo KWL_ParseContent($A["Content"],$CONF['Reply_PLevel']);
				echo "<HR>";

				if ($reply) echo "</TD></TR></TABLE>\n";
					$sql	= "SELECT * from T_Comments ";
					$sql .= "WHERE ParentRid = '" . $A["Rid"] . "' ";
					$sql .= "AND TopRid = '" . $toprid . "' ";
					$sql .= "ORDER By Birthstamp DESC";
					$tresult	= SqlQuery($sql);
					if (mysql_num_rows($tresult)) {
						$tmp	= $reply + 1;
						print_replys($A["Rid"],$toprid,$where,$tmp);
					}
					mysql_free_result($tresult);
			}
		mysql_free_result($result);
		}
	}
}

echo "<!-- " . _PRINTFRIEND . " -->\n\n";
$A = SqlQueryFetchArray("SELECT * FROM T_Stories WHERE Rid = '$story'");

if (!$A) {

	$VAR["Heading"] = _NOSTORY;
	$VAR["Content"] = "<br>" . _NOSTORY . "<br><br>";
	KWL_DrawMain($VAR);

} else {
	
	$content = KWL_ParseContent($A["Content"],$A["ParseLevel"]);

	echo "<FONT SIZE=\"+1\">"
     . _TITLE  . ": <B>$A[Heading]</B>"
	  . "</FONT><P>"
	  . _AUTHOR . ": $A[Author]<BR>"
	  . _POSTEDON . ": " . KWL_DateFormat($A["Birthstamp"]) . "<BR>"
	  . "URL : <A HREF=\"$G_URL/?story=$story\">$G_URL/?story=$story</A>"
	  . "<BR>\n<HR>\n"
	  . $content;
	  
	if ($A['bofile']) {
		echo "<P>\n<LI>". _ATTCHED_FILE .": "
		   . "<a href=\"$G_URL/upload/$A[Topic]/$A[bcfile]/$A[bofile]\">"
			. KWL_icon_check($A['bofile'])
			. "$A[bofile]</a> (" . KWL_FileHSize($A['bfsize'],1) . ")\n"
			. KWL_file_view($A['Topic'],$A['bcfile'],$A['bofile']);
	}
	
	echo "\n<HR>\n";

	if ($A['replys']) {
		if (!$reply) {
			echo "<a href=\"print.php?story=$story&reply=yes\">"._COMMENTS."($A[replys])</a><BR>";
		} else {
			print_replys($story,$story,"",0);
		}
	}
}
echo "<div align=right><A HREF=\"$CONF[G_URL]\">" . htmlspecialchars($CONF["SiteName"]) . "</A>" . " - " . htmlspecialchars($CONF["SiteSlogan"]) . "</div>\n" ;
?>
</BODY>
</HTML>
<?
$content = ob_get_contents();
ob_end_clean();
print $content;
ob_start();
?>
